import React, { useState, useContext } from 'react';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var TabContext = React.createContext({
  selectedTab: ''
});

function Tabs(props) {
  TabContext.selectedTab = props.selected;

  var _useState = useState(TabContext),
      tabState = _useState[0],
      updateTabState = _useState[1];

  var className = 'st st-theme-' + (props.theme || 'default');
  className += props.orientation ? ' st-' + props.orientation : '';
  className += props.justified === true ? ' st-justified' : '';

  function handleClick(e) {
    var node = e.target;

    if (node && node.getAttribute('role') === 'tab') {
      updateTabState({
        selectedTab: node.getAttribute('tab')
      });
    }
  }

  return /*#__PURE__*/React.createElement(TabContext.Provider, {
    value: {
      tabState: tabState,
      updateTabState: updateTabState
    }
  }, /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: className,
    onClick: handleClick
  }), props.children));
}

function TabNav(props) {
  return /*#__PURE__*/React.createElement("ul", _extends({}, props, {
    className: "nav",
    role: "tablist"
  }), props.children);
}

function TabNavItem(props) {
  var _useContext = useContext(TabContext),
      tabState = _useContext.tabState;

  var isActive = tabState.selectedTab && tabState.selectedTab === props.tab;
  return /*#__PURE__*/React.createElement("li", {
    role: "presentation"
  }, /*#__PURE__*/React.createElement("a", _extends({}, props, {
    href: '#' + props.tab,
    tab: props.tab,
    className: 'nav-link ' + (isActive ? 'active' : ''),
    role: "tab",
    "aria-selected": isActive ? 'true' : 'false',
    "aria-disabled": props.disabled ? 'true' : 'false',
    "aria-controls": props.tab
  }), props.children));
}

function TabContent(props) {
  var _useContext = useContext(TabContext),
      tabState = _useContext.tabState;

  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: 'tab-content ' + (tabState.selected || 'no')
  }), props.children);
}

function TabPanel(props) {
  var _useContext = useContext(TabContext),
      tabState = _useContext.tabState;

  var isActive = tabState.selectedTab && tabState.selectedTab === props.id;
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: 'tab-pane ' + isActive + ' ' + (isActive ? 'active' : ''),
    role: "tabpanel",
    "aria-labelledby": props.id
  }), props.children);
}

export { TabContent, TabNav, TabNavItem, TabPanel, Tabs };
//# sourceMappingURL=index.modern.js.map
